@@ -1,9 +1,9 @@
 use proc_macro2::TokenStream;
 use quote::{quote, ToTokens};
-use syn::spanned::Spanned;
 use syn::{FnArg, GenericParam, ItemFn, Pat, ReturnType, Signature, Type};
 
 use crate::functions::Attributes;
+use crate::surrogates::read_surrogates;
 use crate::util;
 
 pub fn fn_signature_type(signature: Signature) -> TokenStream {
@@ -61,7 +61,7 @@ pub fn rval_tokens(return_type: &ReturnType) -> TokenStream {
     }
 }
 
-pub fn ffi_function_freestanding(ffi_attributes: &Attributes, input: TokenStream) -> TokenStream {
+pub fn ffi_function_freestanding(_ffi_attributes: &Attributes, input: TokenStream) -> TokenStream {
     let item_fn: ItemFn = syn::parse2(input.clone()).expect("Must be item.");
     let docs = util::extract_doc_lines(&item_fn.attrs);
 
@@ -70,9 +70,9 @@ pub fn ffi_function_freestanding(ffi_attributes: &Attributes, input: TokenStream
     let mut generic_parameters = Vec::new();
     let mut generic_ident = Vec::new();
 
-    let span = item_fn.span();
     let signature = fn_signature_type(item_fn.sig.clone());
     let rval = rval_tokens(&item_fn.sig.output);
+    let surrogates = read_surrogates(&item_fn.attrs);
 
     for generic in &item_fn.sig.generics.params {
         match generic {
@@ -103,31 +103,32 @@ pub fn ffi_function_freestanding(ffi_attributes: &Attributes, input: TokenStream
         if let FnArg::Typed(pat) = arg {
             let name = match pat.pat.as_ref() {
                 Pat::Ident(ident) => ident.ident.to_string(),
-                Pat::Wild(_) => "_".to_string(),
+                Pat::Wild(_) => "_ignored".to_string(),
                 _ => {
                     panic!("Only supports normal identifiers for parameters, e.g., `x: ...`");
                 }
             };
 
-            args_name.push(name.clone());
+            let clean_name = name.strip_prefix('_').unwrap_or(&name);
+            args_name.push(clean_name.to_string());
 
-            if ffi_attributes.surrogates.contains_key(&name) {
-                let lookup = ffi_attributes.surrogates.get(&name).unwrap();
-                let ident = syn::Ident::new(&lookup, span);
+            let token = match util::purge_lifetimes_from_type(pat.ty.as_ref()) {
+                Type::Path(x) => x.path.to_token_stream(),
+                Type::Reference(x) => x.to_token_stream(),
+                Type::Group(x) => x.to_token_stream(),
+                Type::Ptr(x) => x.to_token_stream(),
+                Type::Array(x) => x.to_token_stream(),
+                Type::BareFn(x) => x.to_token_stream(),
+                _ => {
+                    panic!("Unsupported type at interface boundary found for parameter: {:?}.", pat.ty)
+                }
+            };
+
+            if surrogates.1.contains_key(&name) {
+                let lookup = surrogates.1.get(&name).unwrap();
+                let ident = syn::Ident::new(&lookup, surrogates.0.unwrap());
                 args_type.push(quote! { #ident()  })
             } else {
-                let token = match util::purge_lifetimes_from_type(pat.ty.as_ref()) {
-                    Type::Path(x) => x.path.to_token_stream(),
-                    Type::Reference(x) => x.to_token_stream(),
-                    Type::Group(x) => x.to_token_stream(),
-                    Type::Ptr(x) => x.to_token_stream(),
-                    Type::Array(x) => x.to_token_stream(),
-                    Type::BareFn(x) => x.to_token_stream(),
-                    _ => {
-                        panic!("Unsupported type at interface boundary found for parameter: {:?}.", pat.ty)
-                    }
-                };
-
                 args_type.push(quote! { < #token as interoptopus::lang::rust::CTypeInfo>::type_info() });
             }
         } else {
