@@ -118,11 +118,14 @@ pub fn generate_service_method(attributes: &Attributes, impl_block: &ItemImpl, f
             quote! {
                 #[interoptopus::ffi_function]
                 #[no_mangle]
+                #[allow(unused_mut)]
                 #(
                     #[doc = #doc_lines]
                 )*
                 pub extern "C" fn #ffi_fn_ident #generics( #(#inputs),* ) -> #error_ident {
 
+                    *context = ::std::ptr::null_mut();
+
                     let result_result = std::panic::catch_unwind(|| {
                         <#service_type>::#orig_fn_ident( #(#arg_names),* )
                     });
@@ -154,6 +157,7 @@ pub fn generate_service_method(attributes: &Attributes, impl_block: &ItemImpl, f
                 quote! {
                     #[interoptopus::ffi_function]
                     #[no_mangle]
+                    #[allow(unused_mut)]
                     #(
                         #[doc = #doc_lines]
                     )*
@@ -175,6 +179,7 @@ pub fn generate_service_method(attributes: &Attributes, impl_block: &ItemImpl, f
                 quote! {
                     #[interoptopus::ffi_function]
                     #[no_mangle]
+                    #[allow(unused_mut)]
                     #(
                         #[doc = #doc_lines]
                     )*
@@ -209,8 +214,14 @@ pub fn generate_service_dtor(attributes: &Attributes, impl_block: &ItemImpl) ->
         /// The passed parameter MUST have been created with the corresponding init function;
         /// passing any other value results in undefined behavior.
         #[interoptopus::ffi_function]
+        #[allow(unused_mut)]
         #[no_mangle]
         pub unsafe extern "C" fn #ffi_fn_ident(context: &mut *mut #without_lifetimes) -> #error_ident {
+            // Checks the _contained_ pointer is not null, which usually means service was not initialized.
+            if context.is_null() {
+                return <#error_ident as ::interoptopus::patterns::result::FFIError>::NULL;
+            }
+
             let result_result = std::panic::catch_unwind(std::panic::AssertUnwindSafe(|| {
                 unsafe { Box::from_raw(*context) };
             }));
